# coding: utf-8

"""
    candidates-api-activities

    The Note APIs allows you to Add, Get, Update and Delete Notes.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class FetchCandidateNotesData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'decision_status': 'str',
        'job_id': 'str',
        'note_type': 'str',
        'recruiter_email': 'str',
        'recruiter_name': 'str',
        'from_name': 'str',
        'updated_date': 'str',
        'created_date': 'str',
        'notes': 'str'
    }

    attribute_map = {
        'decision_status': 'decision_status',
        'job_id': 'jobId',
        'note_type': 'noteType',
        'recruiter_email': 'recruiterEmail',
        'recruiter_name': 'recruiterName',
        'from_name': 'fromName',
        'updated_date': 'updatedDate',
        'created_date': 'createdDate',
        'notes': 'notes'
    }

    def __init__(self, decision_status=None, job_id=None, note_type=None, recruiter_email=None, recruiter_name=None, from_name=None, updated_date=None, created_date=None, notes=None):  # noqa: E501
        """FetchCandidateNotesData - a model defined in Swagger"""  # noqa: E501
        self._decision_status = None
        self._job_id = None
        self._note_type = None
        self._recruiter_email = None
        self._recruiter_name = None
        self._from_name = None
        self._updated_date = None
        self._created_date = None
        self._notes = None
        self.discriminator = None
        self.decision_status = decision_status
        self.job_id = job_id
        self.note_type = note_type
        self.recruiter_email = recruiter_email
        self.recruiter_name = recruiter_name
        self.from_name = from_name
        self.updated_date = updated_date
        self.created_date = created_date
        self.notes = notes

    @property
    def decision_status(self):
        """Gets the decision_status of this FetchCandidateNotesData.  # noqa: E501

        The decision status.  # noqa: E501

        :return: The decision_status of this FetchCandidateNotesData.  # noqa: E501
        :rtype: str
        """
        return self._decision_status

    @decision_status.setter
    def decision_status(self, decision_status):
        """Sets the decision_status of this FetchCandidateNotesData.

        The decision status.  # noqa: E501

        :param decision_status: The decision_status of this FetchCandidateNotesData.  # noqa: E501
        :type: str
        """
        if decision_status is None:
            raise ValueError("Invalid value for `decision_status`, must not be `None`")  # noqa: E501

        self._decision_status = decision_status

    @property
    def job_id(self):
        """Gets the job_id of this FetchCandidateNotesData.  # noqa: E501

        The unique identifier for job.  # noqa: E501

        :return: The job_id of this FetchCandidateNotesData.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this FetchCandidateNotesData.

        The unique identifier for job.  # noqa: E501

        :param job_id: The job_id of this FetchCandidateNotesData.  # noqa: E501
        :type: str
        """
        if job_id is None:
            raise ValueError("Invalid value for `job_id`, must not be `None`")  # noqa: E501

        self._job_id = job_id

    @property
    def note_type(self):
        """Gets the note_type of this FetchCandidateNotesData.  # noqa: E501

        The type of note.  # noqa: E501

        :return: The note_type of this FetchCandidateNotesData.  # noqa: E501
        :rtype: str
        """
        return self._note_type

    @note_type.setter
    def note_type(self, note_type):
        """Sets the note_type of this FetchCandidateNotesData.

        The type of note.  # noqa: E501

        :param note_type: The note_type of this FetchCandidateNotesData.  # noqa: E501
        :type: str
        """
        if note_type is None:
            raise ValueError("Invalid value for `note_type`, must not be `None`")  # noqa: E501

        self._note_type = note_type

    @property
    def recruiter_email(self):
        """Gets the recruiter_email of this FetchCandidateNotesData.  # noqa: E501

        The email of the recruiter.  # noqa: E501

        :return: The recruiter_email of this FetchCandidateNotesData.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_email

    @recruiter_email.setter
    def recruiter_email(self, recruiter_email):
        """Sets the recruiter_email of this FetchCandidateNotesData.

        The email of the recruiter.  # noqa: E501

        :param recruiter_email: The recruiter_email of this FetchCandidateNotesData.  # noqa: E501
        :type: str
        """
        if recruiter_email is None:
            raise ValueError("Invalid value for `recruiter_email`, must not be `None`")  # noqa: E501

        self._recruiter_email = recruiter_email

    @property
    def recruiter_name(self):
        """Gets the recruiter_name of this FetchCandidateNotesData.  # noqa: E501

        The name of the recruiter.  # noqa: E501

        :return: The recruiter_name of this FetchCandidateNotesData.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_name

    @recruiter_name.setter
    def recruiter_name(self, recruiter_name):
        """Sets the recruiter_name of this FetchCandidateNotesData.

        The name of the recruiter.  # noqa: E501

        :param recruiter_name: The recruiter_name of this FetchCandidateNotesData.  # noqa: E501
        :type: str
        """
        if recruiter_name is None:
            raise ValueError("Invalid value for `recruiter_name`, must not be `None`")  # noqa: E501

        self._recruiter_name = recruiter_name

    @property
    def from_name(self):
        """Gets the from_name of this FetchCandidateNotesData.  # noqa: E501

        From Name.  # noqa: E501

        :return: The from_name of this FetchCandidateNotesData.  # noqa: E501
        :rtype: str
        """
        return self._from_name

    @from_name.setter
    def from_name(self, from_name):
        """Sets the from_name of this FetchCandidateNotesData.

        From Name.  # noqa: E501

        :param from_name: The from_name of this FetchCandidateNotesData.  # noqa: E501
        :type: str
        """
        if from_name is None:
            raise ValueError("Invalid value for `from_name`, must not be `None`")  # noqa: E501

        self._from_name = from_name

    @property
    def updated_date(self):
        """Gets the updated_date of this FetchCandidateNotesData.  # noqa: E501

        The date on which the note has been updated.  # noqa: E501

        :return: The updated_date of this FetchCandidateNotesData.  # noqa: E501
        :rtype: str
        """
        return self._updated_date

    @updated_date.setter
    def updated_date(self, updated_date):
        """Sets the updated_date of this FetchCandidateNotesData.

        The date on which the note has been updated.  # noqa: E501

        :param updated_date: The updated_date of this FetchCandidateNotesData.  # noqa: E501
        :type: str
        """
        if updated_date is None:
            raise ValueError("Invalid value for `updated_date`, must not be `None`")  # noqa: E501

        self._updated_date = updated_date

    @property
    def created_date(self):
        """Gets the created_date of this FetchCandidateNotesData.  # noqa: E501

        The date on which note has been created.  # noqa: E501

        :return: The created_date of this FetchCandidateNotesData.  # noqa: E501
        :rtype: str
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this FetchCandidateNotesData.

        The date on which note has been created.  # noqa: E501

        :param created_date: The created_date of this FetchCandidateNotesData.  # noqa: E501
        :type: str
        """
        if created_date is None:
            raise ValueError("Invalid value for `created_date`, must not be `None`")  # noqa: E501

        self._created_date = created_date

    @property
    def notes(self):
        """Gets the notes of this FetchCandidateNotesData.  # noqa: E501

        The Notes.  # noqa: E501

        :return: The notes of this FetchCandidateNotesData.  # noqa: E501
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """Sets the notes of this FetchCandidateNotesData.

        The Notes.  # noqa: E501

        :param notes: The notes of this FetchCandidateNotesData.  # noqa: E501
        :type: str
        """
        if notes is None:
            raise ValueError("Invalid value for `notes`, must not be `None`")  # noqa: E501

        self._notes = notes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FetchCandidateNotesData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FetchCandidateNotesData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class Error(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'str',
        'message': 'str'
    }

    attribute_map = {
        'status': 'status',
        'message': 'message'
    }

    def __init__(self, status=None, message=None):  # noqa: E501
        """Error - a model defined in Swagger"""  # noqa: E501
        self._status = None
        self._message = None
        self.discriminator = None
        if status is not None:
            self.status = status
        if message is not None:
            self.message = message

    @property
    def status(self):
        """Gets the status of this Error.  # noqa: E501

        Status code or identifier indicating the nature of the error.  # noqa: E501

        :return: The status of this Error.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Error.

        Status code or identifier indicating the nature of the error.  # noqa: E501

        :param status: The status of this Error.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def message(self):
        """Gets the message of this Error.  # noqa: E501

        Error message providing details about the encountered issue.  # noqa: E501

        :return: The message of this Error.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this Error.

        Error message providing details about the encountered issue.  # noqa: E501

        :param message: The message of this Error.  # noqa: E501
        :type: str
        """

        self._message = message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Error, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Error):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetInterviewDetailsForEvaluatingResponseDataQuestions(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'video_screen_question_id': 'str',
        'question_text': 'str',
        'response_duration_limit_in_sec': 'float',
        'video_id': 'str',
        'think_time_in_sec': 'float',
        'answer_time_in_sec': 'float',
        'answered': 'bool',
        'max_number_retakes': 'float',
        'pending_retakes': 'float',
        'timed': 'bool',
        'type': 'str',
        'settings': 'object',
        'question_id': 'str'
    }

    attribute_map = {
        'video_screen_question_id': 'videoScreenQuestionId',
        'question_text': 'questionText',
        'response_duration_limit_in_sec': 'responseDurationLimitInSec',
        'video_id': 'videoId',
        'think_time_in_sec': 'thinkTimeInSec',
        'answer_time_in_sec': 'answerTimeInSec',
        'answered': 'answered',
        'max_number_retakes': 'maxNumberRetakes',
        'pending_retakes': 'pendingRetakes',
        'timed': 'timed',
        'type': 'type',
        'settings': 'settings',
        'question_id': 'questionId'
    }

    def __init__(self, video_screen_question_id=None, question_text=None, response_duration_limit_in_sec=None, video_id=None, think_time_in_sec=None, answer_time_in_sec=None, answered=None, max_number_retakes=None, pending_retakes=None, timed=None, type=None, settings=None, question_id=None):  # noqa: E501
        """GetInterviewDetailsForEvaluatingResponseDataQuestions - a model defined in Swagger"""  # noqa: E501
        self._video_screen_question_id = None
        self._question_text = None
        self._response_duration_limit_in_sec = None
        self._video_id = None
        self._think_time_in_sec = None
        self._answer_time_in_sec = None
        self._answered = None
        self._max_number_retakes = None
        self._pending_retakes = None
        self._timed = None
        self._type = None
        self._settings = None
        self._question_id = None
        self.discriminator = None
        self.video_screen_question_id = video_screen_question_id
        self.question_text = question_text
        self.response_duration_limit_in_sec = response_duration_limit_in_sec
        self.video_id = video_id
        self.think_time_in_sec = think_time_in_sec
        self.answer_time_in_sec = answer_time_in_sec
        self.answered = answered
        self.max_number_retakes = max_number_retakes
        self.pending_retakes = pending_retakes
        self.timed = timed
        self.type = type
        self.settings = settings
        self.question_id = question_id

    @property
    def video_screen_question_id(self):
        """Gets the video_screen_question_id of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501

        This is the interview question id, this differs from actual question id created from create question api.  # noqa: E501

        :return: The video_screen_question_id of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :rtype: str
        """
        return self._video_screen_question_id

    @video_screen_question_id.setter
    def video_screen_question_id(self, video_screen_question_id):
        """Sets the video_screen_question_id of this GetInterviewDetailsForEvaluatingResponseDataQuestions.

        This is the interview question id, this differs from actual question id created from create question api.  # noqa: E501

        :param video_screen_question_id: The video_screen_question_id of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :type: str
        """
        if video_screen_question_id is None:
            raise ValueError("Invalid value for `video_screen_question_id`, must not be `None`")  # noqa: E501

        self._video_screen_question_id = video_screen_question_id

    @property
    def question_text(self):
        """Gets the question_text of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501

        Question text for the question.  # noqa: E501

        :return: The question_text of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :rtype: str
        """
        return self._question_text

    @question_text.setter
    def question_text(self, question_text):
        """Sets the question_text of this GetInterviewDetailsForEvaluatingResponseDataQuestions.

        Question text for the question.  # noqa: E501

        :param question_text: The question_text of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :type: str
        """
        if question_text is None:
            raise ValueError("Invalid value for `question_text`, must not be `None`")  # noqa: E501

        self._question_text = question_text

    @property
    def response_duration_limit_in_sec(self):
        """Gets the response_duration_limit_in_sec of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501

        Max recording duration allowed for a question.  # noqa: E501

        :return: The response_duration_limit_in_sec of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :rtype: float
        """
        return self._response_duration_limit_in_sec

    @response_duration_limit_in_sec.setter
    def response_duration_limit_in_sec(self, response_duration_limit_in_sec):
        """Sets the response_duration_limit_in_sec of this GetInterviewDetailsForEvaluatingResponseDataQuestions.

        Max recording duration allowed for a question.  # noqa: E501

        :param response_duration_limit_in_sec: The response_duration_limit_in_sec of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :type: float
        """
        if response_duration_limit_in_sec is None:
            raise ValueError("Invalid value for `response_duration_limit_in_sec`, must not be `None`")  # noqa: E501

        self._response_duration_limit_in_sec = response_duration_limit_in_sec

    @property
    def video_id(self):
        """Gets the video_id of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501

        This field is applicable for media question video or audio etc.  # noqa: E501

        :return: The video_id of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :rtype: str
        """
        return self._video_id

    @video_id.setter
    def video_id(self, video_id):
        """Sets the video_id of this GetInterviewDetailsForEvaluatingResponseDataQuestions.

        This field is applicable for media question video or audio etc.  # noqa: E501

        :param video_id: The video_id of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :type: str
        """
        if video_id is None:
            raise ValueError("Invalid value for `video_id`, must not be `None`")  # noqa: E501

        self._video_id = video_id

    @property
    def think_time_in_sec(self):
        """Gets the think_time_in_sec of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501

        This is the preparation time given for the question before recording the actual answer.  # noqa: E501

        :return: The think_time_in_sec of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :rtype: float
        """
        return self._think_time_in_sec

    @think_time_in_sec.setter
    def think_time_in_sec(self, think_time_in_sec):
        """Sets the think_time_in_sec of this GetInterviewDetailsForEvaluatingResponseDataQuestions.

        This is the preparation time given for the question before recording the actual answer.  # noqa: E501

        :param think_time_in_sec: The think_time_in_sec of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :type: float
        """
        if think_time_in_sec is None:
            raise ValueError("Invalid value for `think_time_in_sec`, must not be `None`")  # noqa: E501

        self._think_time_in_sec = think_time_in_sec

    @property
    def answer_time_in_sec(self):
        """Gets the answer_time_in_sec of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501

        This field is applicable for non media question.  # noqa: E501

        :return: The answer_time_in_sec of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :rtype: float
        """
        return self._answer_time_in_sec

    @answer_time_in_sec.setter
    def answer_time_in_sec(self, answer_time_in_sec):
        """Sets the answer_time_in_sec of this GetInterviewDetailsForEvaluatingResponseDataQuestions.

        This field is applicable for non media question.  # noqa: E501

        :param answer_time_in_sec: The answer_time_in_sec of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :type: float
        """
        if answer_time_in_sec is None:
            raise ValueError("Invalid value for `answer_time_in_sec`, must not be `None`")  # noqa: E501

        self._answer_time_in_sec = answer_time_in_sec

    @property
    def answered(self):
        """Gets the answered of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501

        Indicates whether question is answered.  # noqa: E501

        :return: The answered of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :rtype: bool
        """
        return self._answered

    @answered.setter
    def answered(self, answered):
        """Sets the answered of this GetInterviewDetailsForEvaluatingResponseDataQuestions.

        Indicates whether question is answered.  # noqa: E501

        :param answered: The answered of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :type: bool
        """
        if answered is None:
            raise ValueError("Invalid value for `answered`, must not be `None`")  # noqa: E501

        self._answered = answered

    @property
    def max_number_retakes(self):
        """Gets the max_number_retakes of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501

        Max number of retakes allowed for a media question.  # noqa: E501

        :return: The max_number_retakes of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :rtype: float
        """
        return self._max_number_retakes

    @max_number_retakes.setter
    def max_number_retakes(self, max_number_retakes):
        """Sets the max_number_retakes of this GetInterviewDetailsForEvaluatingResponseDataQuestions.

        Max number of retakes allowed for a media question.  # noqa: E501

        :param max_number_retakes: The max_number_retakes of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :type: float
        """
        if max_number_retakes is None:
            raise ValueError("Invalid value for `max_number_retakes`, must not be `None`")  # noqa: E501

        self._max_number_retakes = max_number_retakes

    @property
    def pending_retakes(self):
        """Gets the pending_retakes of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501

        Pending retakes for a question.  # noqa: E501

        :return: The pending_retakes of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :rtype: float
        """
        return self._pending_retakes

    @pending_retakes.setter
    def pending_retakes(self, pending_retakes):
        """Sets the pending_retakes of this GetInterviewDetailsForEvaluatingResponseDataQuestions.

        Pending retakes for a question.  # noqa: E501

        :param pending_retakes: The pending_retakes of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :type: float
        """
        if pending_retakes is None:
            raise ValueError("Invalid value for `pending_retakes`, must not be `None`")  # noqa: E501

        self._pending_retakes = pending_retakes

    @property
    def timed(self):
        """Gets the timed of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501

        Indicates whether timer applied to a non media question.  # noqa: E501

        :return: The timed of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :rtype: bool
        """
        return self._timed

    @timed.setter
    def timed(self, timed):
        """Sets the timed of this GetInterviewDetailsForEvaluatingResponseDataQuestions.

        Indicates whether timer applied to a non media question.  # noqa: E501

        :param timed: The timed of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :type: bool
        """
        if timed is None:
            raise ValueError("Invalid value for `timed`, must not be `None`")  # noqa: E501

        self._timed = timed

    @property
    def type(self):
        """Gets the type of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501

        Question type can be a video, audio etc.  # noqa: E501

        :return: The type of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this GetInterviewDetailsForEvaluatingResponseDataQuestions.

        Question type can be a video, audio etc.  # noqa: E501

        :param type: The type of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def settings(self):
        """Gets the settings of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501

        Settings object is dynamic.  # noqa: E501

        :return: The settings of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :rtype: object
        """
        return self._settings

    @settings.setter
    def settings(self, settings):
        """Sets the settings of this GetInterviewDetailsForEvaluatingResponseDataQuestions.

        Settings object is dynamic.  # noqa: E501

        :param settings: The settings of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :type: object
        """
        if settings is None:
            raise ValueError("Invalid value for `settings`, must not be `None`")  # noqa: E501

        self._settings = settings

    @property
    def question_id(self):
        """Gets the question_id of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501

        Actual question id of the question created.  # noqa: E501

        :return: The question_id of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :rtype: str
        """
        return self._question_id

    @question_id.setter
    def question_id(self, question_id):
        """Sets the question_id of this GetInterviewDetailsForEvaluatingResponseDataQuestions.

        Actual question id of the question created.  # noqa: E501

        :param question_id: The question_id of this GetInterviewDetailsForEvaluatingResponseDataQuestions.  # noqa: E501
        :type: str
        """
        if question_id is None:
            raise ValueError("Invalid value for `question_id`, must not be `None`")  # noqa: E501

        self._question_id = question_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetInterviewDetailsForEvaluatingResponseDataQuestions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetInterviewDetailsForEvaluatingResponseDataQuestions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    candidates-api-activities

    The Note APIs allows you to Add, Get, Update and Delete Notes.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class UpdateCandidateNote(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'note_type': 'str',
        'note_text': 'str',
        'as_private': 'bool',
        'recruiter_name': 'str'
    }

    attribute_map = {
        'note_type': 'noteType',
        'note_text': 'noteText',
        'as_private': 'asPrivate',
        'recruiter_name': 'recruiterName'
    }

    def __init__(self, note_type=None, note_text=None, as_private=None, recruiter_name=None):  # noqa: E501
        """UpdateCandidateNote - a model defined in Swagger"""  # noqa: E501
        self._note_type = None
        self._note_text = None
        self._as_private = None
        self._recruiter_name = None
        self.discriminator = None
        if note_type is not None:
            self.note_type = note_type
        if note_text is not None:
            self.note_text = note_text
        if as_private is not None:
            self.as_private = as_private
        if recruiter_name is not None:
            self.recruiter_name = recruiter_name

    @property
    def note_type(self):
        """Gets the note_type of this UpdateCandidateNote.  # noqa: E501

        The type of the candidate note. Specifies the category of the note associated with the candidate.  # noqa: E501

        :return: The note_type of this UpdateCandidateNote.  # noqa: E501
        :rtype: str
        """
        return self._note_type

    @note_type.setter
    def note_type(self, note_type):
        """Sets the note_type of this UpdateCandidateNote.

        The type of the candidate note. Specifies the category of the note associated with the candidate.  # noqa: E501

        :param note_type: The note_type of this UpdateCandidateNote.  # noqa: E501
        :type: str
        """

        self._note_type = note_type

    @property
    def note_text(self):
        """Gets the note_text of this UpdateCandidateNote.  # noqa: E501

        The text content of the candidate note.  # noqa: E501

        :return: The note_text of this UpdateCandidateNote.  # noqa: E501
        :rtype: str
        """
        return self._note_text

    @note_text.setter
    def note_text(self, note_text):
        """Sets the note_text of this UpdateCandidateNote.

        The text content of the candidate note.  # noqa: E501

        :param note_text: The note_text of this UpdateCandidateNote.  # noqa: E501
        :type: str
        """

        self._note_text = note_text

    @property
    def as_private(self):
        """Gets the as_private of this UpdateCandidateNote.  # noqa: E501

        A boolean flag indicating whether the candidate note is private. If true, the note is intended to be visible only to individuals who created it.  # noqa: E501

        :return: The as_private of this UpdateCandidateNote.  # noqa: E501
        :rtype: bool
        """
        return self._as_private

    @as_private.setter
    def as_private(self, as_private):
        """Sets the as_private of this UpdateCandidateNote.

        A boolean flag indicating whether the candidate note is private. If true, the note is intended to be visible only to individuals who created it.  # noqa: E501

        :param as_private: The as_private of this UpdateCandidateNote.  # noqa: E501
        :type: bool
        """

        self._as_private = as_private

    @property
    def recruiter_name(self):
        """Gets the recruiter_name of this UpdateCandidateNote.  # noqa: E501

        The name of the recruiter updating the candidate note. This field identifies the recruiter associated with the modification.  # noqa: E501

        :return: The recruiter_name of this UpdateCandidateNote.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_name

    @recruiter_name.setter
    def recruiter_name(self, recruiter_name):
        """Sets the recruiter_name of this UpdateCandidateNote.

        The name of the recruiter updating the candidate note. This field identifies the recruiter associated with the modification.  # noqa: E501

        :param recruiter_name: The recruiter_name of this UpdateCandidateNote.  # noqa: E501
        :type: str
        """

        self._recruiter_name = recruiter_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateCandidateNote, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateCandidateNote):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from phenom.api.applicants.applicants_api import ApplicantsApi
from phenom.api.applicants.leads_api import LeadsApi
from phenom.api.applicants.activity_api import ActivityApi
from phenom.api.applicants.hiring_status_api import HiringStatusApi
from phenom.api.applicants.candidates_attachments_api import CandidatesAttachmentsApi

class Applicants(object):
    def __init__(self, token, gateway_url, apikey=None):
        self.__token = token
        self.__gateway_url = gateway_url
        self.__apikey = apikey

    # applicants apis
    def applicants_api(self):
        return ApplicantsApi(self.__token, self.__gateway_url, self.__apikey)

    def activity_api(self):
        return ActivityApi(self.__token, self.__gateway_url, self.__apikey)

    def hiring_status_api(self):
        return HiringStatusApi(self.__token, self.__gateway_url, self.__apikey)

    def leads_api(self):
        return LeadsApi(self.__token, self.__gateway_url, self.__apikey)

    def candidates_attachments_api(self):
        return CandidatesAttachmentsApi(self.__token, self.__gateway_url, self.__apikey)


# coding: utf-8

"""
    jobs-activities-api

    These API's allows you to perform activities on Jobs  # noqa: E501

    OpenAPI spec version: 1.0.3
    
    Generated by: phenom
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phenom.commons.api_client import ApiClient


class JobAttachmentsApi(object):
    base_path = "/jobs-api/activities"  # your base path

    def __init__(self, token, gateway_url, apikey, api_client=None):
        if api_client is None:
            api_client = ApiClient(gateway_url + self.base_path, apikey, token)
        self.api_client = api_client

    def get_job_attachments(self, job_id, x_ph_userid, **kwargs):  # noqa: E501
        """Get Attachments  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_job_attachments(job_id, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id: jobId (required)
        :param str x_ph_userid: (required)
        :return: GetJobAttachmentsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_job_attachments_with_http_info(job_id, x_ph_userid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_job_attachments_with_http_info(job_id, x_ph_userid, **kwargs)  # noqa: E501
            return data

    def get_job_attachments_with_http_info(self, job_id, x_ph_userid, **kwargs):  # noqa: E501
        """Get Attachments  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_job_attachments_with_http_info(job_id, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id: jobId (required)
        :param str x_ph_userid: (required)
        :return: GetJobAttachmentsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['job_id', 'x_ph_userid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_job_attachments" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'job_id' is set
        if ('job_id' not in params or
                params['job_id'] is None):
            raise ValueError("Missing the required parameter `job_id` when calling `get_job_attachments`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `get_job_attachments`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'job_id' in params:
            path_params['jobId'] = params['job_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/jobs/{jobId}/attachments', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetJobAttachmentsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

# flake8: noqa

"""
    apply-api

    The Apply API allows for seamless integration of the Phenom systems, enabling partners to push applications directly. This API also enables partners to integrate the Phenom Quick application process into their own job boards, while still maintaining control over the candidate experience. As a result, candidates can submit their applications without needing to visit the customer career site.  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.apply.applications_api import ApplicationsApi
from phenom.api.apply.attachments_api import AttachmentsApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.apply.models.address_data import AddressData
from phenom.api.apply.models.already_applied_data import AlreadyAppliedData
from phenom.api.apply.models.already_applied_response import AlreadyAppliedResponse
from phenom.api.apply.models.application_with_id import ApplicationWithId
from phenom.api.apply.models.application_with_id_and_resume import ApplicationWithIdAndResume
from phenom.api.apply.models.application_with_resume import ApplicationWithResume
from phenom.api.apply.models.candidate import Candidate
from phenom.api.apply.models.candidate_with_id import CandidateWithId
from phenom.api.apply.models.contact_data import ContactData
from phenom.api.apply.models.education_data import EducationData
from phenom.api.apply.models.error_response import ErrorResponse
from phenom.api.apply.models.experience_data import ExperienceData
from phenom.api.apply.models.from_to import FromTo
from phenom.api.apply.models.get_application_by_id_response import GetApplicationByIdResponse
from phenom.api.apply.models.get_applications_response import GetApplicationsResponse
from phenom.api.apply.models.get_attachments_response import GetAttachmentsResponse
from phenom.api.apply.models.job import Job
from phenom.api.apply.models.links import Links
from phenom.api.apply.models.pagination import Pagination
from phenom.api.apply.models.resume import Resume
from phenom.api.apply.models.submit_application_data import SubmitApplicationData
from phenom.api.apply.models.submit_application_response import SubmitApplicationResponse
from phenom.api.apply.models.success_response import SuccessResponse
from phenom.api.apply.models.upload_attachment_response import UploadAttachmentResponse



# coding: utf-8

"""
    apply-api

    The Apply API allows for seamless integration of the Phenom systems, enabling partners to push applications directly. This API also enables partners to integrate the Phenom Quick application process into their own job boards, while still maintaining control over the candidate experience. As a result, candidates can submit their applications without needing to visit the customer career site.  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class FromTo(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'format': 'str',
        'start_date': 'str',
        'end_date': 'str',
        'currently_work_here': 'str'
    }

    attribute_map = {
        'format': 'format',
        'start_date': 'startDate',
        'end_date': 'endDate',
        'currently_work_here': 'currentlyWorkHere'
    }

    def __init__(self, format=None, start_date=None, end_date=None, currently_work_here=None):  # noqa: E501
        """FromTo - a model defined in Swagger"""  # noqa: E501
        self._format = None
        self._start_date = None
        self._end_date = None
        self._currently_work_here = None
        self.discriminator = None
        self.format = format
        self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date
        if currently_work_here is not None:
            self.currently_work_here = currently_work_here

    @property
    def format(self):
        """Gets the format of this FromTo.  # noqa: E501

        The date format for the date fields. It should follow the following formats: [MM-yyyy,MM,yyyy].  # noqa: E501

        :return: The format of this FromTo.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this FromTo.

        The date format for the date fields. It should follow the following formats: [MM-yyyy,MM,yyyy].  # noqa: E501

        :param format: The format of this FromTo.  # noqa: E501
        :type: str
        """
        if format is None:
            raise ValueError("Invalid value for `format`, must not be `None`")  # noqa: E501

        self._format = format

    @property
    def start_date(self):
        """Gets the start_date of this FromTo.  # noqa: E501

        The start date of the experience.  # noqa: E501

        :return: The start_date of this FromTo.  # noqa: E501
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this FromTo.

        The start date of the experience.  # noqa: E501

        :param start_date: The start_date of this FromTo.  # noqa: E501
        :type: str
        """
        if start_date is None:
            raise ValueError("Invalid value for `start_date`, must not be `None`")  # noqa: E501

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this FromTo.  # noqa: E501

        The end date of the experience. If the experience is ongoing, this field should be empty.  # noqa: E501

        :return: The end_date of this FromTo.  # noqa: E501
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this FromTo.

        The end date of the experience. If the experience is ongoing, this field should be empty.  # noqa: E501

        :param end_date: The end_date of this FromTo.  # noqa: E501
        :type: str
        """

        self._end_date = end_date

    @property
    def currently_work_here(self):
        """Gets the currently_work_here of this FromTo.  # noqa: E501

        The current status of the experience.  # noqa: E501

        :return: The currently_work_here of this FromTo.  # noqa: E501
        :rtype: str
        """
        return self._currently_work_here

    @currently_work_here.setter
    def currently_work_here(self, currently_work_here):
        """Sets the currently_work_here of this FromTo.

        The current status of the experience.  # noqa: E501

        :param currently_work_here: The currently_work_here of this FromTo.  # noqa: E501
        :type: str
        """

        self._currently_work_here = currently_work_here

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FromTo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FromTo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.hrm.jobs_api import JobsApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.hrm.models.bad_request import BadRequest
from phenom.api.hrm.models.get_candidates_request import GetCandidatesRequest
from phenom.api.hrm.models.get_candidates_request_filters import GetCandidatesRequestFilters
from phenom.api.hrm.models.get_candidates_request_sort_by import GetCandidatesRequestSortBy
from phenom.api.hrm.models.get_candidates_response import GetCandidatesResponse
from phenom.api.hrm.models.get_candidates_response_data import GetCandidatesResponseData
from phenom.api.hrm.models.get_candidates_response_data_attachments import GetCandidatesResponseDataAttachments
from phenom.api.hrm.models.get_candidates_response_data_candidates import GetCandidatesResponseDataCandidates
from phenom.api.hrm.models.get_candidates_response_data_current_company import GetCandidatesResponseDataCurrentCompany
from phenom.api.hrm.models.get_candidates_response_data_email_list import GetCandidatesResponseDataEmailList
from phenom.api.hrm.models.get_candidates_response_data_hiring_manager_review_status import GetCandidatesResponseDataHiringManagerReviewStatus
from phenom.api.hrm.models.get_candidates_response_data_hiring_status import GetCandidatesResponseDataHiringStatus
from phenom.api.hrm.models.get_candidates_response_data_on_demand_interview_screening import GetCandidatesResponseDataOnDemandInterviewScreening
from phenom.api.hrm.models.get_candidates_response_data_recruiter_forward_info import GetCandidatesResponseDataRecruiterForwardInfo
from phenom.api.hrm.models.get_candidates_response_data_social_profile import GetCandidatesResponseDataSocialProfile
from phenom.api.hrm.models.internal_server_error import InternalServerError
from phenom.api.hrm.models.job_details import JobDetails
from phenom.api.hrm.models.job_details_assigned import JobDetailsAssigned
from phenom.api.hrm.models.job_details_fit_score_meta_data import JobDetailsFitScoreMetaData
from phenom.api.hrm.models.job_details_hiring_manager import JobDetailsHiringManager
from phenom.api.hrm.models.job_details_hiring_manager_list import JobDetailsHiringManagerList
from phenom.api.hrm.models.job_details_hiring_team_list import JobDetailsHiringTeamList
from phenom.api.hrm.models.job_details_lat_long import JobDetailsLatLong
from phenom.api.hrm.models.job_details_multi_category import JobDetailsMultiCategory
from phenom.api.hrm.models.job_details_multi_location import JobDetailsMultiLocation
from phenom.api.hrm.models.job_details_onet import JobDetailsOnet
from phenom.api.hrm.models.job_details_posted_by import JobDetailsPostedBy
from phenom.api.hrm.models.job_details_publish_to import JobDetailsPublishTo
from phenom.api.hrm.models.job_details_relation_type import JobDetailsRelationType
from phenom.api.hrm.models.job_details_tenant_specific_additional_fields import JobDetailsTenantSpecificAdditionalFields
from phenom.api.hrm.models.job_details_variations import JobDetailsVariations
from phenom.api.hrm.models.job_id_details import JobIdDetails
from phenom.api.hrm.models.job_id_details_data import JobIdDetailsData
from phenom.api.hrm.models.jobs_list_request import JobsListRequest
from phenom.api.hrm.models.jobs_list_request_sort_by import JobsListRequestSortBy
from phenom.api.hrm.models.jobs_list_response import JobsListResponse
from phenom.api.hrm.models.jobs_list_response_data import JobsListResponseData
from phenom.api.hrm.models.mark_read_status import MarkReadStatus
from phenom.api.hrm.models.pending_tasks_count import PendingTasksCount
from phenom.api.hrm.models.pending_tasks_count_data import PendingTasksCountData
from phenom.api.hrm.models.task_details_request import TaskDetailsRequest
from phenom.api.hrm.models.task_details_response import TaskDetailsResponse
from phenom.api.hrm.models.task_details_response_data import TaskDetailsResponseData
from phenom.api.hrm.models.task_details_response_data_jobs_info import TaskDetailsResponseDataJobsInfo
from phenom.api.hrm.models.unauthorized_request import UnauthorizedRequest



# coding: utf-8

"""
    jobsync-api

    Job Sync enables the user to manage jobs (view, create, update and delete jobs) in the Phenom database directly from the ATS, with the updates reflected on the career site.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: shravan.malla@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobsListSuccessResponse(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'str',
        'offset': 'int',
        'limit': 'int',
        'total_records_count': 'int',
        'data': 'list[JobResponseDTO]'
    }

    attribute_map = {
        'status': 'status',
        'offset': 'offset',
        'limit': 'limit',
        'total_records_count': 'totalRecordsCount',
        'data': 'data'
    }

    def __init__(self, status=None, offset=None, limit=None, total_records_count=None, data=None):  # noqa: E501
        """JobsListSuccessResponse - a model defined in Swagger"""  # noqa: E501
        self._status = None
        self._offset = None
        self._limit = None
        self._total_records_count = None
        self._data = None
        self.discriminator = None
        if status is not None:
            self.status = status
        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit
        if total_records_count is not None:
            self.total_records_count = total_records_count
        if data is not None:
            self.data = data

    @property
    def status(self):
        """Gets the status of this JobsListSuccessResponse.  # noqa: E501

        Status of the response.  # noqa: E501

        :return: The status of this JobsListSuccessResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this JobsListSuccessResponse.

        Status of the response.  # noqa: E501

        :param status: The status of this JobsListSuccessResponse.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def offset(self):
        """Gets the offset of this JobsListSuccessResponse.  # noqa: E501

        Parameter defines from which point to query for jobs.  # noqa: E501

        :return: The offset of this JobsListSuccessResponse.  # noqa: E501
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this JobsListSuccessResponse.

        Parameter defines from which point to query for jobs.  # noqa: E501

        :param offset: The offset of this JobsListSuccessResponse.  # noqa: E501
        :type: int
        """

        self._offset = offset

    @property
    def limit(self):
        """Gets the limit of this JobsListSuccessResponse.  # noqa: E501

        Parameter defines how many jobs to query.  # noqa: E501

        :return: The limit of this JobsListSuccessResponse.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this JobsListSuccessResponse.

        Parameter defines how many jobs to query.  # noqa: E501

        :param limit: The limit of this JobsListSuccessResponse.  # noqa: E501
        :type: int
        """

        self._limit = limit

    @property
    def total_records_count(self):
        """Gets the total_records_count of this JobsListSuccessResponse.  # noqa: E501

        Total number of jobs for given query.  # noqa: E501

        :return: The total_records_count of this JobsListSuccessResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_records_count

    @total_records_count.setter
    def total_records_count(self, total_records_count):
        """Sets the total_records_count of this JobsListSuccessResponse.

        Total number of jobs for given query.  # noqa: E501

        :param total_records_count: The total_records_count of this JobsListSuccessResponse.  # noqa: E501
        :type: int
        """

        self._total_records_count = total_records_count

    @property
    def data(self):
        """Gets the data of this JobsListSuccessResponse.  # noqa: E501

        List of jobs.  # noqa: E501

        :return: The data of this JobsListSuccessResponse.  # noqa: E501
        :rtype: list[JobResponseDTO]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this JobsListSuccessResponse.

        List of jobs.  # noqa: E501

        :param data: The data of this JobsListSuccessResponse.  # noqa: E501
        :type: list[JobResponseDTO]
        """

        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobsListSuccessResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobsListSuccessResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class UpdateQuestionnaireRequestQuestions(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'question_id': 'str',
        'question_translations': 'list[UpdateQuestionnaireRequestQuestionTranslations]',
        'question_text': 'str',
        'type': 'str',
        'response_duration_limit_in_sec': 'float',
        'max_number_retakes': 'float',
        'date_created': 'int',
        'last_updated': 'int',
        'settings': 'object',
        'options': 'object'
    }

    attribute_map = {
        'question_id': 'questionId',
        'question_translations': 'questionTranslations',
        'question_text': 'questionText',
        'type': 'type',
        'response_duration_limit_in_sec': 'responseDurationLimitInSec',
        'max_number_retakes': 'maxNumberRetakes',
        'date_created': 'dateCreated',
        'last_updated': 'lastUpdated',
        'settings': 'settings',
        'options': 'options'
    }

    def __init__(self, question_id=None, question_translations=None, question_text=None, type=None, response_duration_limit_in_sec=None, max_number_retakes=None, date_created=None, last_updated=None, settings=None, options=None):  # noqa: E501
        """UpdateQuestionnaireRequestQuestions - a model defined in Swagger"""  # noqa: E501
        self._question_id = None
        self._question_translations = None
        self._question_text = None
        self._type = None
        self._response_duration_limit_in_sec = None
        self._max_number_retakes = None
        self._date_created = None
        self._last_updated = None
        self._settings = None
        self._options = None
        self.discriminator = None
        self.question_id = question_id
        self.question_translations = question_translations
        self.question_text = question_text
        self.type = type
        if response_duration_limit_in_sec is not None:
            self.response_duration_limit_in_sec = response_duration_limit_in_sec
        if max_number_retakes is not None:
            self.max_number_retakes = max_number_retakes
        self.date_created = date_created
        self.last_updated = last_updated
        if settings is not None:
            self.settings = settings
        if options is not None:
            self.options = options

    @property
    def question_id(self):
        """Gets the question_id of this UpdateQuestionnaireRequestQuestions.  # noqa: E501

        Question id of the question.  # noqa: E501

        :return: The question_id of this UpdateQuestionnaireRequestQuestions.  # noqa: E501
        :rtype: str
        """
        return self._question_id

    @question_id.setter
    def question_id(self, question_id):
        """Sets the question_id of this UpdateQuestionnaireRequestQuestions.

        Question id of the question.  # noqa: E501

        :param question_id: The question_id of this UpdateQuestionnaireRequestQuestions.  # noqa: E501
        :type: str
        """
        if question_id is None:
            raise ValueError("Invalid value for `question_id`, must not be `None`")  # noqa: E501

        self._question_id = question_id

    @property
    def question_translations(self):
        """Gets the question_translations of this UpdateQuestionnaireRequestQuestions.  # noqa: E501

        Contains translated questions for a locale.  # noqa: E501

        :return: The question_translations of this UpdateQuestionnaireRequestQuestions.  # noqa: E501
        :rtype: list[UpdateQuestionnaireRequestQuestionTranslations]
        """
        return self._question_translations

    @question_translations.setter
    def question_translations(self, question_translations):
        """Sets the question_translations of this UpdateQuestionnaireRequestQuestions.

        Contains translated questions for a locale.  # noqa: E501

        :param question_translations: The question_translations of this UpdateQuestionnaireRequestQuestions.  # noqa: E501
        :type: list[UpdateQuestionnaireRequestQuestionTranslations]
        """
        if question_translations is None:
            raise ValueError("Invalid value for `question_translations`, must not be `None`")  # noqa: E501

        self._question_translations = question_translations

    @property
    def question_text(self):
        """Gets the question_text of this UpdateQuestionnaireRequestQuestions.  # noqa: E501

        Question text for the question.  # noqa: E501

        :return: The question_text of this UpdateQuestionnaireRequestQuestions.  # noqa: E501
        :rtype: str
        """
        return self._question_text

    @question_text.setter
    def question_text(self, question_text):
        """Sets the question_text of this UpdateQuestionnaireRequestQuestions.

        Question text for the question.  # noqa: E501

        :param question_text: The question_text of this UpdateQuestionnaireRequestQuestions.  # noqa: E501
        :type: str
        """
        if question_text is None:
            raise ValueError("Invalid value for `question_text`, must not be `None`")  # noqa: E501

        self._question_text = question_text

    @property
    def type(self):
        """Gets the type of this UpdateQuestionnaireRequestQuestions.  # noqa: E501

        Type of the question, could be video, audio, videoOrAudio, multiple, scored, single, knockout, text.  # noqa: E501

        :return: The type of this UpdateQuestionnaireRequestQuestions.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this UpdateQuestionnaireRequestQuestions.

        Type of the question, could be video, audio, videoOrAudio, multiple, scored, single, knockout, text.  # noqa: E501

        :param type: The type of this UpdateQuestionnaireRequestQuestions.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def response_duration_limit_in_sec(self):
        """Gets the response_duration_limit_in_sec of this UpdateQuestionnaireRequestQuestions.  # noqa: E501

        Time limit for the question to be answered.  # noqa: E501

        :return: The response_duration_limit_in_sec of this UpdateQuestionnaireRequestQuestions.  # noqa: E501
        :rtype: float
        """
        return self._response_duration_limit_in_sec

    @response_duration_limit_in_sec.setter
    def response_duration_limit_in_sec(self, response_duration_limit_in_sec):
        """Sets the response_duration_limit_in_sec of this UpdateQuestionnaireRequestQuestions.

        Time limit for the question to be answered.  # noqa: E501

        :param response_duration_limit_in_sec: The response_duration_limit_in_sec of this UpdateQuestionnaireRequestQuestions.  # noqa: E501
        :type: float
        """

        self._response_duration_limit_in_sec = response_duration_limit_in_sec

    @property
    def max_number_retakes(self):
        """Gets the max_number_retakes of this UpdateQuestionnaireRequestQuestions.  # noqa: E501

        Max number of times the question can be retaken.  # noqa: E501

        :return: The max_number_retakes of this UpdateQuestionnaireRequestQuestions.  # noqa: E501
        :rtype: float
        """
        return self._max_number_retakes

    @max_number_retakes.setter
    def max_number_retakes(self, max_number_retakes):
        """Sets the max_number_retakes of this UpdateQuestionnaireRequestQuestions.

        Max number of times the question can be retaken.  # noqa: E501

        :param max_number_retakes: The max_number_retakes of this UpdateQuestionnaireRequestQuestions.  # noqa: E501
        :type: float
        """

        self._max_number_retakes = max_number_retakes

    @property
    def date_created(self):
        """Gets the date_created of this UpdateQuestionnaireRequestQuestions.  # noqa: E501

        Date when the question is created.  # noqa: E501

        :return: The date_created of this UpdateQuestionnaireRequestQuestions.  # noqa: E501
        :rtype: int
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this UpdateQuestionnaireRequestQuestions.

        Date when the question is created.  # noqa: E501

        :param date_created: The date_created of this UpdateQuestionnaireRequestQuestions.  # noqa: E501
        :type: int
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def last_updated(self):
        """Gets the last_updated of this UpdateQuestionnaireRequestQuestions.  # noqa: E501

        Date when the question is updated.  # noqa: E501

        :return: The last_updated of this UpdateQuestionnaireRequestQuestions.  # noqa: E501
        :rtype: int
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """Sets the last_updated of this UpdateQuestionnaireRequestQuestions.

        Date when the question is updated.  # noqa: E501

        :param last_updated: The last_updated of this UpdateQuestionnaireRequestQuestions.  # noqa: E501
        :type: int
        """
        if last_updated is None:
            raise ValueError("Invalid value for `last_updated`, must not be `None`")  # noqa: E501

        self._last_updated = last_updated

    @property
    def settings(self):
        """Gets the settings of this UpdateQuestionnaireRequestQuestions.  # noqa: E501

        Settings object is dynamic, It could contain either numberOfChoice, numberOfCharacters. So based on response for question type you should added the fields in your respective class later.  # noqa: E501

        :return: The settings of this UpdateQuestionnaireRequestQuestions.  # noqa: E501
        :rtype: object
        """
        return self._settings

    @settings.setter
    def settings(self, settings):
        """Sets the settings of this UpdateQuestionnaireRequestQuestions.

        Settings object is dynamic, It could contain either numberOfChoice, numberOfCharacters. So based on response for question type you should added the fields in your respective class later.  # noqa: E501

        :param settings: The settings of this UpdateQuestionnaireRequestQuestions.  # noqa: E501
        :type: object
        """

        self._settings = settings

    @property
    def options(self):
        """Gets the options of this UpdateQuestionnaireRequestQuestions.  # noqa: E501

        This gives the locale specific options.  # noqa: E501

        :return: The options of this UpdateQuestionnaireRequestQuestions.  # noqa: E501
        :rtype: object
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this UpdateQuestionnaireRequestQuestions.

        This gives the locale specific options.  # noqa: E501

        :param options: The options of this UpdateQuestionnaireRequestQuestions.  # noqa: E501
        :type: object
        """

        self._options = options

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateQuestionnaireRequestQuestions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateQuestionnaireRequestQuestions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    campaigns-email

    These APIs ensures an easy integration process of Email management for developers to send, read, and track Email campaigns within applications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class EmailCampaignHistoryData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'email': 'str',
        'email_activity_id': 'str',
        'campaign_name': 'str',
        'campaign_type': 'str',
        'created_date': 'int'
    }

    attribute_map = {
        'email': 'email',
        'email_activity_id': 'emailActivityId',
        'campaign_name': 'campaignName',
        'campaign_type': 'campaignType',
        'created_date': 'createdDate'
    }

    def __init__(self, email=None, email_activity_id=None, campaign_name=None, campaign_type=None, created_date=None):  # noqa: E501
        """EmailCampaignHistoryData - a model defined in Swagger"""  # noqa: E501
        self._email = None
        self._email_activity_id = None
        self._campaign_name = None
        self._campaign_type = None
        self._created_date = None
        self.discriminator = None
        self.email = email
        self.email_activity_id = email_activity_id
        self.campaign_name = campaign_name
        self.campaign_type = campaign_type
        self.created_date = created_date

    @property
    def email(self):
        """Gets the email of this EmailCampaignHistoryData.  # noqa: E501

        Email associated with Email campaign History.  # noqa: E501

        :return: The email of this EmailCampaignHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this EmailCampaignHistoryData.

        Email associated with Email campaign History.  # noqa: E501

        :param email: The email of this EmailCampaignHistoryData.  # noqa: E501
        :type: str
        """
        if email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def email_activity_id(self):
        """Gets the email_activity_id of this EmailCampaignHistoryData.  # noqa: E501

        Email Activity Id associated with Email Campaign History.  # noqa: E501

        :return: The email_activity_id of this EmailCampaignHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._email_activity_id

    @email_activity_id.setter
    def email_activity_id(self, email_activity_id):
        """Sets the email_activity_id of this EmailCampaignHistoryData.

        Email Activity Id associated with Email Campaign History.  # noqa: E501

        :param email_activity_id: The email_activity_id of this EmailCampaignHistoryData.  # noqa: E501
        :type: str
        """
        if email_activity_id is None:
            raise ValueError("Invalid value for `email_activity_id`, must not be `None`")  # noqa: E501

        self._email_activity_id = email_activity_id

    @property
    def campaign_name(self):
        """Gets the campaign_name of this EmailCampaignHistoryData.  # noqa: E501

        The Email CampaignName in the Email Campaign History.  # noqa: E501

        :return: The campaign_name of this EmailCampaignHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._campaign_name

    @campaign_name.setter
    def campaign_name(self, campaign_name):
        """Sets the campaign_name of this EmailCampaignHistoryData.

        The Email CampaignName in the Email Campaign History.  # noqa: E501

        :param campaign_name: The campaign_name of this EmailCampaignHistoryData.  # noqa: E501
        :type: str
        """
        if campaign_name is None:
            raise ValueError("Invalid value for `campaign_name`, must not be `None`")  # noqa: E501

        self._campaign_name = campaign_name

    @property
    def campaign_type(self):
        """Gets the campaign_type of this EmailCampaignHistoryData.  # noqa: E501

        Type of the email campaign in the Email Campaign History .  # noqa: E501

        :return: The campaign_type of this EmailCampaignHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._campaign_type

    @campaign_type.setter
    def campaign_type(self, campaign_type):
        """Sets the campaign_type of this EmailCampaignHistoryData.

        Type of the email campaign in the Email Campaign History .  # noqa: E501

        :param campaign_type: The campaign_type of this EmailCampaignHistoryData.  # noqa: E501
        :type: str
        """
        if campaign_type is None:
            raise ValueError("Invalid value for `campaign_type`, must not be `None`")  # noqa: E501

        self._campaign_type = campaign_type

    @property
    def created_date(self):
        """Gets the created_date of this EmailCampaignHistoryData.  # noqa: E501

        Timestamp indicating when the email campaign history entry was created.  # noqa: E501

        :return: The created_date of this EmailCampaignHistoryData.  # noqa: E501
        :rtype: int
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this EmailCampaignHistoryData.

        Timestamp indicating when the email campaign history entry was created.  # noqa: E501

        :param created_date: The created_date of this EmailCampaignHistoryData.  # noqa: E501
        :type: int
        """
        if created_date is None:
            raise ValueError("Invalid value for `created_date`, must not be `None`")  # noqa: E501

        self._created_date = created_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EmailCampaignHistoryData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailCampaignHistoryData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from phenom.api.apply.attachments_api import AttachmentsApi
from phenom.api.apply.applications_api import ApplicationsApi

class Applications(object):
    def __init__(self, token, gateway_url, apikey=None):
        self.__token = token
        self.__gateway_url = gateway_url
        self.__apikey = apikey

    # applications apis
    def attachments_api(self):
        return AttachmentsApi(self.__token, self.__gateway_url, self.__apikey)

    def applications_api(self):
        return ApplicationsApi(self.__token, self.__gateway_url, self.__apikey)


from phenom.api.communicationssms.sms_communications_api import SMSCommunicationsApi
from phenom.api.communicationsemail.email_communications_api import EmailCommunicationsApi
from phenom.api.communicationsemail.forward_profile_api import ForwardProfileApi

class Communications(object):
    def __init__(self, token, gateway_url, apikey=None):
        self.__token = token
        self.__gateway_url = gateway_url
        self.__apikey = apikey

    def sms_communications_api(self):
        return SMSCommunicationsApi(self.__token, self.__gateway_url, self.__apikey)

    def email_communications_api(self):
        return EmailCommunicationsApi(self.__token, self.__gateway_url, self.__apikey)

    def forward_profile_api(self):
        return ForwardProfileApi(self.__token, self.__gateway_url, self.__apikey)


# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobDetailsHiringTeamList(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'role': 'str',
        'name': 'str',
        'email_id': 'str',
        'id': 'str',
        'source': 'str',
        'type': 'str'
    }

    attribute_map = {
        'role': 'role',
        'name': 'name',
        'email_id': 'emailId',
        'id': 'id',
        'source': 'source',
        'type': 'type'
    }

    def __init__(self, role=None, name=None, email_id=None, id=None, source=None, type=None):  # noqa: E501
        """JobDetailsHiringTeamList - a model defined in Swagger"""  # noqa: E501
        self._role = None
        self._name = None
        self._email_id = None
        self._id = None
        self._source = None
        self._type = None
        self.discriminator = None
        if role is not None:
            self.role = role
        if name is not None:
            self.name = name
        if email_id is not None:
            self.email_id = email_id
        if id is not None:
            self.id = id
        if source is not None:
            self.source = source
        if type is not None:
            self.type = type

    @property
    def role(self):
        """Gets the role of this JobDetailsHiringTeamList.  # noqa: E501

        Role of the team member related to the job.  # noqa: E501

        :return: The role of this JobDetailsHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this JobDetailsHiringTeamList.

        Role of the team member related to the job.  # noqa: E501

        :param role: The role of this JobDetailsHiringTeamList.  # noqa: E501
        :type: str
        """

        self._role = role

    @property
    def name(self):
        """Gets the name of this JobDetailsHiringTeamList.  # noqa: E501

        Name of the team member.  # noqa: E501

        :return: The name of this JobDetailsHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this JobDetailsHiringTeamList.

        Name of the team member.  # noqa: E501

        :param name: The name of this JobDetailsHiringTeamList.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def email_id(self):
        """Gets the email_id of this JobDetailsHiringTeamList.  # noqa: E501

        Email ID of the team member.  # noqa: E501

        :return: The email_id of this JobDetailsHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._email_id

    @email_id.setter
    def email_id(self, email_id):
        """Sets the email_id of this JobDetailsHiringTeamList.

        Email ID of the team member.  # noqa: E501

        :param email_id: The email_id of this JobDetailsHiringTeamList.  # noqa: E501
        :type: str
        """

        self._email_id = email_id

    @property
    def id(self):
        """Gets the id of this JobDetailsHiringTeamList.  # noqa: E501

        Unique ID of the team member.  # noqa: E501

        :return: The id of this JobDetailsHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this JobDetailsHiringTeamList.

        Unique ID of the team member.  # noqa: E501

        :param id: The id of this JobDetailsHiringTeamList.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def source(self):
        """Gets the source of this JobDetailsHiringTeamList.  # noqa: E501

        Source from where the team member was added.  # noqa: E501

        :return: The source of this JobDetailsHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this JobDetailsHiringTeamList.

        Source from where the team member was added.  # noqa: E501

        :param source: The source of this JobDetailsHiringTeamList.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def type(self):
        """Gets the type of this JobDetailsHiringTeamList.  # noqa: E501

        Type of the team member.  # noqa: E501

        :return: The type of this JobDetailsHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this JobDetailsHiringTeamList.

        Type of the team member.  # noqa: E501

        :param type: The type of this JobDetailsHiringTeamList.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobDetailsHiringTeamList, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobDetailsHiringTeamList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    jobsync-api

    Job Sync enables the user to manage jobs (view, create, update and delete jobs) in the Phenom database directly from the ATS, with the updates reflected on the career site.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: shravan.malla@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ErrorResponse(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'timestamp': 'str',
        'status': 'str',
        'error': 'str',
        'path': 'str'
    }

    attribute_map = {
        'timestamp': 'timestamp',
        'status': 'status',
        'error': 'error',
        'path': 'path'
    }

    def __init__(self, timestamp=None, status=None, error=None, path=None):  # noqa: E501
        """ErrorResponse - a model defined in Swagger"""  # noqa: E501
        self._timestamp = None
        self._status = None
        self._error = None
        self._path = None
        self.discriminator = None
        if timestamp is not None:
            self.timestamp = timestamp
        if status is not None:
            self.status = status
        if error is not None:
            self.error = error
        if path is not None:
            self.path = path

    @property
    def timestamp(self):
        """Gets the timestamp of this ErrorResponse.  # noqa: E501

        Timestamp of the error.  # noqa: E501

        :return: The timestamp of this ErrorResponse.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this ErrorResponse.

        Timestamp of the error.  # noqa: E501

        :param timestamp: The timestamp of this ErrorResponse.  # noqa: E501
        :type: str
        """

        self._timestamp = timestamp

    @property
    def status(self):
        """Gets the status of this ErrorResponse.  # noqa: E501

        Status of the response.  # noqa: E501

        :return: The status of this ErrorResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ErrorResponse.

        Status of the response.  # noqa: E501

        :param status: The status of this ErrorResponse.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def error(self):
        """Gets the error of this ErrorResponse.  # noqa: E501

        Error message.  # noqa: E501

        :return: The error of this ErrorResponse.  # noqa: E501
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this ErrorResponse.

        Error message.  # noqa: E501

        :param error: The error of this ErrorResponse.  # noqa: E501
        :type: str
        """

        self._error = error

    @property
    def path(self):
        """Gets the path of this ErrorResponse.  # noqa: E501

        Path of the request.  # noqa: E501

        :return: The path of this ErrorResponse.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this ErrorResponse.

        Path of the request.  # noqa: E501

        :param path: The path of this ErrorResponse.  # noqa: E501
        :type: str
        """

        self._path = path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ErrorResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ErrorResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    candidates-api

    The Candidate APIs allows you to add, update and delete candidates.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class AddOrUpdateExperienceRequestExperience(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'company': 'str',
        'is_current': 'bool',
        'job_title': 'str',
        'job_summary': 'str',
        'start_month': 'int',
        'start_year': 'int',
        'end_month': 'int',
        'end_year': 'int',
        'industry': 'str',
        'type': 'str',
        'designation': 'str',
        'role': 'str',
        'job_location': 'str',
        'country': 'str',
        'state': 'str',
        'city': 'str'
    }

    attribute_map = {
        'company': 'company',
        'is_current': 'isCurrent',
        'job_title': 'jobTitle',
        'job_summary': 'jobSummary',
        'start_month': 'startMonth',
        'start_year': 'startYear',
        'end_month': 'endMonth',
        'end_year': 'endYear',
        'industry': 'industry',
        'type': 'type',
        'designation': 'designation',
        'role': 'role',
        'job_location': 'jobLocation',
        'country': 'country',
        'state': 'state',
        'city': 'city'
    }

    def __init__(self, company=None, is_current=None, job_title=None, job_summary=None, start_month=None, start_year=None, end_month=None, end_year=None, industry=None, type=None, designation=None, role=None, job_location=None, country=None, state=None, city=None):  # noqa: E501
        """AddOrUpdateExperienceRequestExperience - a model defined in Swagger"""  # noqa: E501
        self._company = None
        self._is_current = None
        self._job_title = None
        self._job_summary = None
        self._start_month = None
        self._start_year = None
        self._end_month = None
        self._end_year = None
        self._industry = None
        self._type = None
        self._designation = None
        self._role = None
        self._job_location = None
        self._country = None
        self._state = None
        self._city = None
        self.discriminator = None
        if company is not None:
            self.company = company
        if is_current is not None:
            self.is_current = is_current
        if job_title is not None:
            self.job_title = job_title
        if job_summary is not None:
            self.job_summary = job_summary
        if start_month is not None:
            self.start_month = start_month
        if start_year is not None:
            self.start_year = start_year
        if end_month is not None:
            self.end_month = end_month
        if end_year is not None:
            self.end_year = end_year
        if industry is not None:
            self.industry = industry
        if type is not None:
            self.type = type
        if designation is not None:
            self.designation = designation
        if role is not None:
            self.role = role
        if job_location is not None:
            self.job_location = job_location
        if country is not None:
            self.country = country
        if state is not None:
            self.state = state
        if city is not None:
            self.city = city

    @property
    def company(self):
        """Gets the company of this AddOrUpdateExperienceRequestExperience.  # noqa: E501

        The name of the company where the candidate gained experience.  # noqa: E501

        :return: The company of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :rtype: str
        """
        return self._company

    @company.setter
    def company(self, company):
        """Sets the company of this AddOrUpdateExperienceRequestExperience.

        The name of the company where the candidate gained experience.  # noqa: E501

        :param company: The company of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :type: str
        """

        self._company = company

    @property
    def is_current(self):
        """Gets the is_current of this AddOrUpdateExperienceRequestExperience.  # noqa: E501

        Indicates whether the candidate is currently employed in this position.  # noqa: E501

        :return: The is_current of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :rtype: bool
        """
        return self._is_current

    @is_current.setter
    def is_current(self, is_current):
        """Sets the is_current of this AddOrUpdateExperienceRequestExperience.

        Indicates whether the candidate is currently employed in this position.  # noqa: E501

        :param is_current: The is_current of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :type: bool
        """

        self._is_current = is_current

    @property
    def job_title(self):
        """Gets the job_title of this AddOrUpdateExperienceRequestExperience.  # noqa: E501

        The job title or position held by the candidate.  # noqa: E501

        :return: The job_title of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :rtype: str
        """
        return self._job_title

    @job_title.setter
    def job_title(self, job_title):
        """Sets the job_title of this AddOrUpdateExperienceRequestExperience.

        The job title or position held by the candidate.  # noqa: E501

        :param job_title: The job_title of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :type: str
        """

        self._job_title = job_title

    @property
    def job_summary(self):
        """Gets the job_summary of this AddOrUpdateExperienceRequestExperience.  # noqa: E501

        A summary or description of the candidate's job responsibilities.  # noqa: E501

        :return: The job_summary of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :rtype: str
        """
        return self._job_summary

    @job_summary.setter
    def job_summary(self, job_summary):
        """Sets the job_summary of this AddOrUpdateExperienceRequestExperience.

        A summary or description of the candidate's job responsibilities.  # noqa: E501

        :param job_summary: The job_summary of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :type: str
        """

        self._job_summary = job_summary

    @property
    def start_month(self):
        """Gets the start_month of this AddOrUpdateExperienceRequestExperience.  # noqa: E501

        The starting month of the candidate's employment.  # noqa: E501

        :return: The start_month of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :rtype: int
        """
        return self._start_month

    @start_month.setter
    def start_month(self, start_month):
        """Sets the start_month of this AddOrUpdateExperienceRequestExperience.

        The starting month of the candidate's employment.  # noqa: E501

        :param start_month: The start_month of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :type: int
        """

        self._start_month = start_month

    @property
    def start_year(self):
        """Gets the start_year of this AddOrUpdateExperienceRequestExperience.  # noqa: E501

        The starting year of the candidate's employment.  # noqa: E501

        :return: The start_year of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :rtype: int
        """
        return self._start_year

    @start_year.setter
    def start_year(self, start_year):
        """Sets the start_year of this AddOrUpdateExperienceRequestExperience.

        The starting year of the candidate's employment.  # noqa: E501

        :param start_year: The start_year of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :type: int
        """

        self._start_year = start_year

    @property
    def end_month(self):
        """Gets the end_month of this AddOrUpdateExperienceRequestExperience.  # noqa: E501

        The ending month of the candidate's employment, if applicable.  # noqa: E501

        :return: The end_month of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :rtype: int
        """
        return self._end_month

    @end_month.setter
    def end_month(self, end_month):
        """Sets the end_month of this AddOrUpdateExperienceRequestExperience.

        The ending month of the candidate's employment, if applicable.  # noqa: E501

        :param end_month: The end_month of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :type: int
        """

        self._end_month = end_month

    @property
    def end_year(self):
        """Gets the end_year of this AddOrUpdateExperienceRequestExperience.  # noqa: E501

        The ending year of the candidate's employment, if applicable.  # noqa: E501

        :return: The end_year of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :rtype: int
        """
        return self._end_year

    @end_year.setter
    def end_year(self, end_year):
        """Sets the end_year of this AddOrUpdateExperienceRequestExperience.

        The ending year of the candidate's employment, if applicable.  # noqa: E501

        :param end_year: The end_year of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :type: int
        """

        self._end_year = end_year

    @property
    def industry(self):
        """Gets the industry of this AddOrUpdateExperienceRequestExperience.  # noqa: E501

        The industry or sector associated with the candidate's experience.  # noqa: E501

        :return: The industry of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :rtype: str
        """
        return self._industry

    @industry.setter
    def industry(self, industry):
        """Sets the industry of this AddOrUpdateExperienceRequestExperience.

        The industry or sector associated with the candidate's experience.  # noqa: E501

        :param industry: The industry of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :type: str
        """

        self._industry = industry

    @property
    def type(self):
        """Gets the type of this AddOrUpdateExperienceRequestExperience.  # noqa: E501

        The type of experience (e.g., 'Full-time', 'Part-time').  # noqa: E501

        :return: The type of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this AddOrUpdateExperienceRequestExperience.

        The type of experience (e.g., 'Full-time', 'Part-time').  # noqa: E501

        :param type: The type of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def designation(self):
        """Gets the designation of this AddOrUpdateExperienceRequestExperience.  # noqa: E501

        The designation or role associated with the candidate's experience.  # noqa: E501

        :return: The designation of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :rtype: str
        """
        return self._designation

    @designation.setter
    def designation(self, designation):
        """Sets the designation of this AddOrUpdateExperienceRequestExperience.

        The designation or role associated with the candidate's experience.  # noqa: E501

        :param designation: The designation of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :type: str
        """

        self._designation = designation

    @property
    def role(self):
        """Gets the role of this AddOrUpdateExperienceRequestExperience.  # noqa: E501

        The specific role or function performed by the candidate.  # noqa: E501

        :return: The role of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this AddOrUpdateExperienceRequestExperience.

        The specific role or function performed by the candidate.  # noqa: E501

        :param role: The role of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :type: str
        """

        self._role = role

    @property
    def job_location(self):
        """Gets the job_location of this AddOrUpdateExperienceRequestExperience.  # noqa: E501

        The location of the job or work associated with the experience.  # noqa: E501

        :return: The job_location of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :rtype: str
        """
        return self._job_location

    @job_location.setter
    def job_location(self, job_location):
        """Sets the job_location of this AddOrUpdateExperienceRequestExperience.

        The location of the job or work associated with the experience.  # noqa: E501

        :param job_location: The job_location of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :type: str
        """

        self._job_location = job_location

    @property
    def country(self):
        """Gets the country of this AddOrUpdateExperienceRequestExperience.  # noqa: E501

        The country where the candidate gained experience.  # noqa: E501

        :return: The country of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this AddOrUpdateExperienceRequestExperience.

        The country where the candidate gained experience.  # noqa: E501

        :param country: The country of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def state(self):
        """Gets the state of this AddOrUpdateExperienceRequestExperience.  # noqa: E501

        The state or region where the candidate gained experience.  # noqa: E501

        :return: The state of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this AddOrUpdateExperienceRequestExperience.

        The state or region where the candidate gained experience.  # noqa: E501

        :param state: The state of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def city(self):
        """Gets the city of this AddOrUpdateExperienceRequestExperience.  # noqa: E501

        The city where the candidate gained experience.  # noqa: E501

        :return: The city of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this AddOrUpdateExperienceRequestExperience.

        The city where the candidate gained experience.  # noqa: E501

        :param city: The city of this AddOrUpdateExperienceRequestExperience.  # noqa: E501
        :type: str
        """

        self._city = city

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddOrUpdateExperienceRequestExperience, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddOrUpdateExperienceRequestExperience):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetCandidatesResponseDataCurrentCompany(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'provided_by_user': 'bool',
        'job_title': 'str',
        'source': 'str',
        'priority': 'float',
        'transaction_id': 'str',
        'field_id': 'str',
        'company': 'str',
        'designation': 'str',
        'standardized_date': 'str'
    }

    attribute_map = {
        'provided_by_user': 'providedByUser',
        'job_title': 'jobTitle',
        'source': 'source',
        'priority': 'priority',
        'transaction_id': 'transactionId',
        'field_id': 'fieldID',
        'company': 'company',
        'designation': 'designation',
        'standardized_date': 'standardizedDate'
    }

    def __init__(self, provided_by_user=None, job_title=None, source=None, priority=None, transaction_id=None, field_id=None, company=None, designation=None, standardized_date=None):  # noqa: E501
        """GetCandidatesResponseDataCurrentCompany - a model defined in Swagger"""  # noqa: E501
        self._provided_by_user = None
        self._job_title = None
        self._source = None
        self._priority = None
        self._transaction_id = None
        self._field_id = None
        self._company = None
        self._designation = None
        self._standardized_date = None
        self.discriminator = None
        if provided_by_user is not None:
            self.provided_by_user = provided_by_user
        if job_title is not None:
            self.job_title = job_title
        if source is not None:
            self.source = source
        if priority is not None:
            self.priority = priority
        if transaction_id is not None:
            self.transaction_id = transaction_id
        if field_id is not None:
            self.field_id = field_id
        if company is not None:
            self.company = company
        if designation is not None:
            self.designation = designation
        if standardized_date is not None:
            self.standardized_date = standardized_date

    @property
    def provided_by_user(self):
        """Gets the provided_by_user of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501

        Indicates if this information is provided by the user.  # noqa: E501

        :return: The provided_by_user of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501
        :rtype: bool
        """
        return self._provided_by_user

    @provided_by_user.setter
    def provided_by_user(self, provided_by_user):
        """Sets the provided_by_user of this GetCandidatesResponseDataCurrentCompany.

        Indicates if this information is provided by the user.  # noqa: E501

        :param provided_by_user: The provided_by_user of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501
        :type: bool
        """

        self._provided_by_user = provided_by_user

    @property
    def job_title(self):
        """Gets the job_title of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501

        Job title of the current company.  # noqa: E501

        :return: The job_title of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501
        :rtype: str
        """
        return self._job_title

    @job_title.setter
    def job_title(self, job_title):
        """Sets the job_title of this GetCandidatesResponseDataCurrentCompany.

        Job title of the current company.  # noqa: E501

        :param job_title: The job_title of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501
        :type: str
        """

        self._job_title = job_title

    @property
    def source(self):
        """Gets the source of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501

        Source of the information.  # noqa: E501

        :return: The source of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this GetCandidatesResponseDataCurrentCompany.

        Source of the information.  # noqa: E501

        :param source: The source of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def priority(self):
        """Gets the priority of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501

        Priority of the current company information.  # noqa: E501

        :return: The priority of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501
        :rtype: float
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this GetCandidatesResponseDataCurrentCompany.

        Priority of the current company information.  # noqa: E501

        :param priority: The priority of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501
        :type: float
        """

        self._priority = priority

    @property
    def transaction_id(self):
        """Gets the transaction_id of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501

        Transaction ID related to the current company.  # noqa: E501

        :return: The transaction_id of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501
        :rtype: str
        """
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, transaction_id):
        """Sets the transaction_id of this GetCandidatesResponseDataCurrentCompany.

        Transaction ID related to the current company.  # noqa: E501

        :param transaction_id: The transaction_id of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501
        :type: str
        """

        self._transaction_id = transaction_id

    @property
    def field_id(self):
        """Gets the field_id of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501

        Field identifier for the current company information.  # noqa: E501

        :return: The field_id of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501
        :rtype: str
        """
        return self._field_id

    @field_id.setter
    def field_id(self, field_id):
        """Sets the field_id of this GetCandidatesResponseDataCurrentCompany.

        Field identifier for the current company information.  # noqa: E501

        :param field_id: The field_id of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501
        :type: str
        """

        self._field_id = field_id

    @property
    def company(self):
        """Gets the company of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501

        Name of the current company.  # noqa: E501

        :return: The company of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501
        :rtype: str
        """
        return self._company

    @company.setter
    def company(self, company):
        """Sets the company of this GetCandidatesResponseDataCurrentCompany.

        Name of the current company.  # noqa: E501

        :param company: The company of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501
        :type: str
        """

        self._company = company

    @property
    def designation(self):
        """Gets the designation of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501

        Designation of the candidate in the current company.  # noqa: E501

        :return: The designation of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501
        :rtype: str
        """
        return self._designation

    @designation.setter
    def designation(self, designation):
        """Sets the designation of this GetCandidatesResponseDataCurrentCompany.

        Designation of the candidate in the current company.  # noqa: E501

        :param designation: The designation of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501
        :type: str
        """

        self._designation = designation

    @property
    def standardized_date(self):
        """Gets the standardized_date of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501

        Standardized date.  # noqa: E501

        :return: The standardized_date of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501
        :rtype: str
        """
        return self._standardized_date

    @standardized_date.setter
    def standardized_date(self, standardized_date):
        """Sets the standardized_date of this GetCandidatesResponseDataCurrentCompany.

        Standardized date.  # noqa: E501

        :param standardized_date: The standardized_date of this GetCandidatesResponseDataCurrentCompany.  # noqa: E501
        :type: str
        """

        self._standardized_date = standardized_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetCandidatesResponseDataCurrentCompany, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetCandidatesResponseDataCurrentCompany):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from phenom.api.evaluation.interview_evaluations_api import InterviewEvaluationsApi
from phenom.api.evaluation.jobs_api import JobsApi

class Evaluations(object):
    def __init__(self, token, gateway_url, apikey=None):
        self.__token = token
        self.__gateway_url = gateway_url
        self.__apikey = apikey
    def interview_evaluations_api(self):
        return InterviewEvaluationsApi(self.__token, self.__gateway_url, self.__apikey)

    def jobs_api(self):
        return JobsApi(self.__token, self.__gateway_url, self.__apikey)


from setuptools import setup, find_packages
VERSION = '0.0.12'
DESCRIPTION = 'Phenom Public Apis SDK for Python'
def read_readme():
    with open('README.md', 'r') as f:
        return f.read()
# Setting up
setup(
    name="phenom-api-management",
    version=VERSION,
    author="phenom",
    author_email="api-management@phenom.com",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=read_readme(),
    packages=find_packages(),
    install_requires=['PyJWT==2.4.0', 'certifi==2024.2.2', 'urllib3==1.26.18', 'six==1.16.0'],
    keywords=['resumeparser', 'exsearch'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3.6",
    ]
)


# coding: utf-8

# flake8: noqa

"""
    evaluation-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.evaluation.interview_evaluations_api import InterviewEvaluationsApi
from phenom.api.evaluation.jobs_api import JobsApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.evaluation.models.candidate_evaluations import CandidateEvaluations
from phenom.api.evaluation.models.candidate_evaluations_data import CandidateEvaluationsData
from phenom.api.evaluation.models.candidate_evaluations_data_candidate_evaluations import CandidateEvaluationsDataCandidateEvaluations
from phenom.api.evaluation.models.candidate_evaluations_data_information import CandidateEvaluationsDataInformation
from phenom.api.evaluation.models.candidate_evaluations_on_job import CandidateEvaluationsOnJob
from phenom.api.evaluation.models.candidate_evaluations_on_job_data import CandidateEvaluationsOnJobData
from phenom.api.evaluation.models.candidate_evaluations_on_job_data_candidate_evaluations import CandidateEvaluationsOnJobDataCandidateEvaluations
from phenom.api.evaluation.models.candidate_evaluations_on_job_data_form_feedback import CandidateEvaluationsOnJobDataFormFeedback
from phenom.api.evaluation.models.candidate_job_evaluation_request import CandidateJobEvaluationRequest
from phenom.api.evaluation.models.candidate_job_evaluation_response import CandidateJobEvaluationResponse
from phenom.api.evaluation.models.evaluate_on_fly_request import EvaluateOnFlyRequest
from phenom.api.evaluation.models.evaluate_on_fly_request_candidate_additional_fields import EvaluateOnFlyRequestCandidateAdditionalFields
from phenom.api.evaluation.models.evaluation_forms_details import EvaluationFormsDetails
from phenom.api.evaluation.models.evaluation_forms_details_data import EvaluationFormsDetailsData
from phenom.api.evaluation.models.evaluation_forms_details_data_evaluation_forms import EvaluationFormsDetailsDataEvaluationForms
from phenom.api.evaluation.models.evaluation_on_fly_response import EvaluationOnFlyResponse
from phenom.api.evaluation.models.evaluations_request import EvaluationsRequest
from phenom.api.evaluation.models.evaluations_request_scope_attr import EvaluationsRequestScopeAttr
from phenom.api.evaluation.models.internal_server_error import InternalServerError
from phenom.api.evaluation.models.job_candidate_status_request import JobCandidateStatusRequest
from phenom.api.evaluation.models.job_candidate_status_response import JobCandidateStatusResponse
from phenom.api.evaluation.models.question_and_answers import QuestionAndAnswers
from phenom.api.evaluation.models.unauthorized_request import UnauthorizedRequest



# coding: utf-8

"""
    candidates-api

    The Candidate APIs allows you to add, update and delete candidates.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class UpdateCandidateRequestContacts(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'phone_number': 'str',
        'status': 'str',
        'country_code': 'str'
    }

    attribute_map = {
        'type': 'type',
        'phone_number': 'phoneNumber',
        'status': 'status',
        'country_code': 'countryCode'
    }

    def __init__(self, type=None, phone_number=None, status=None, country_code=None):  # noqa: E501
        """UpdateCandidateRequestContacts - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._phone_number = None
        self._status = None
        self._country_code = None
        self.discriminator = None
        if type is not None:
            self.type = type
        if phone_number is not None:
            self.phone_number = phone_number
        if status is not None:
            self.status = status
        if country_code is not None:
            self.country_code = country_code

    @property
    def type(self):
        """Gets the type of this UpdateCandidateRequestContacts.  # noqa: E501

        The type of contact (e.g., 'Primary' or 'Secondary').  # noqa: E501

        :return: The type of this UpdateCandidateRequestContacts.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this UpdateCandidateRequestContacts.

        The type of contact (e.g., 'Primary' or 'Secondary').  # noqa: E501

        :param type: The type of this UpdateCandidateRequestContacts.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def phone_number(self):
        """Gets the phone_number of this UpdateCandidateRequestContacts.  # noqa: E501

        The phone number of the contact.  # noqa: E501

        :return: The phone_number of this UpdateCandidateRequestContacts.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this UpdateCandidateRequestContacts.

        The phone number of the contact.  # noqa: E501

        :param phone_number: The phone_number of this UpdateCandidateRequestContacts.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    @property
    def status(self):
        """Gets the status of this UpdateCandidateRequestContacts.  # noqa: E501

        The status of the contact (e.g., 'Primary' or 'Secondary').  # noqa: E501

        :return: The status of this UpdateCandidateRequestContacts.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this UpdateCandidateRequestContacts.

        The status of the contact (e.g., 'Primary' or 'Secondary').  # noqa: E501

        :param status: The status of this UpdateCandidateRequestContacts.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def country_code(self):
        """Gets the country_code of this UpdateCandidateRequestContacts.  # noqa: E501

        The country code associated with the contact.  # noqa: E501

        :return: The country_code of this UpdateCandidateRequestContacts.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this UpdateCandidateRequestContacts.

        The country code associated with the contact.  # noqa: E501

        :param country_code: The country_code of this UpdateCandidateRequestContacts.  # noqa: E501
        :type: str
        """

        self._country_code = country_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateCandidateRequestContacts, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateCandidateRequestContacts):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class AssignCandidatesToProject(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'project_name': 'str',
        'candidate_infos': 'list[AssignCandidatesToProjectCandidateInfos]'
    }

    attribute_map = {
        'project_name': 'projectName',
        'candidate_infos': 'candidateInfos'
    }

    def __init__(self, project_name=None, candidate_infos=None):  # noqa: E501
        """AssignCandidatesToProject - a model defined in Swagger"""  # noqa: E501
        self._project_name = None
        self._candidate_infos = None
        self.discriminator = None
        self.project_name = project_name
        self.candidate_infos = candidate_infos

    @property
    def project_name(self):
        """Gets the project_name of this AssignCandidatesToProject.  # noqa: E501

        Name of the project to which candidates are being assigned.  # noqa: E501

        :return: The project_name of this AssignCandidatesToProject.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this AssignCandidatesToProject.

        Name of the project to which candidates are being assigned.  # noqa: E501

        :param project_name: The project_name of this AssignCandidatesToProject.  # noqa: E501
        :type: str
        """
        if project_name is None:
            raise ValueError("Invalid value for `project_name`, must not be `None`")  # noqa: E501

        self._project_name = project_name

    @property
    def candidate_infos(self):
        """Gets the candidate_infos of this AssignCandidatesToProject.  # noqa: E501

        List of candidate information objects.  # noqa: E501

        :return: The candidate_infos of this AssignCandidatesToProject.  # noqa: E501
        :rtype: list[AssignCandidatesToProjectCandidateInfos]
        """
        return self._candidate_infos

    @candidate_infos.setter
    def candidate_infos(self, candidate_infos):
        """Sets the candidate_infos of this AssignCandidatesToProject.

        List of candidate information objects.  # noqa: E501

        :param candidate_infos: The candidate_infos of this AssignCandidatesToProject.  # noqa: E501
        :type: list[AssignCandidatesToProjectCandidateInfos]
        """
        if candidate_infos is None:
            raise ValueError("Invalid value for `candidate_infos`, must not be `None`")  # noqa: E501

        self._candidate_infos = candidate_infos

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AssignCandidatesToProject, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssignCandidatesToProject):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    candidates-api

    The Candidate APIs allows you to add, update and delete candidates.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class CandidateDataCandidate(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'attachments': 'list[CandidateDataCandidateAttachments]',
        'education': 'list[EducationDataEducations]',
        'middle_name': 'str',
        'language_preference': 'str',
        'language_known': 'list[str]',
        'user_id': 'str',
        'last_update_timestamp': 'float',
        'employee_id': 'str',
        'skills': 'list[str]',
        'linked_in_profile_url': 'str',
        'first_name': 'str',
        'company': 'str',
        'created_date': 'float',
        'new_location': 'CandidateDataCandidateNewLocation',
        'updated_date': 'float',
        'preferred_communication_mode': 'CandidateDataCandidatePreferredCommunicationMode',
        'email_list': 'list[CandidateDataCandidateEmailList]',
        'experience': 'list[CandidateDataCandidateExperience]',
        'contacts': 'list[CandidateDataCandidateContacts]',
        'last_name': 'str',
        'internal': 'bool',
        'ats_id': 'str'
    }

    attribute_map = {
        'attachments': 'attachments',
        'education': 'education',
        'middle_name': 'middleName',
        'language_preference': 'languagePreference',
        'language_known': 'languageKnown',
        'user_id': 'userId',
        'last_update_timestamp': 'lastUpdateTimestamp',
        'employee_id': 'employeeId',
        'skills': 'skills',
        'linked_in_profile_url': 'linkedInProfileURL',
        'first_name': 'firstName',
        'company': 'company',
        'created_date': 'createdDate',
        'new_location': 'newLocation',
        'updated_date': 'updatedDate',
        'preferred_communication_mode': 'preferredCommunicationMode',
        'email_list': 'emailList',
        'experience': 'experience',
        'contacts': 'contacts',
        'last_name': 'lastName',
        'internal': 'internal',
        'ats_id': 'atsId'
    }

    def __init__(self, attachments=None, education=None, middle_name=None, language_preference=None, language_known=None, user_id=None, last_update_timestamp=None, employee_id=None, skills=None, linked_in_profile_url=None, first_name=None, company=None, created_date=None, new_location=None, updated_date=None, preferred_communication_mode=None, email_list=None, experience=None, contacts=None, last_name=None, internal=None, ats_id=None):  # noqa: E501
        """CandidateDataCandidate - a model defined in Swagger"""  # noqa: E501
        self._attachments = None
        self._education = None
        self._middle_name = None
        self._language_preference = None
        self._language_known = None
        self._user_id = None
        self._last_update_timestamp = None
        self._employee_id = None
        self._skills = None
        self._linked_in_profile_url = None
        self._first_name = None
        self._company = None
        self._created_date = None
        self._new_location = None
        self._updated_date = None
        self._preferred_communication_mode = None
        self._email_list = None
        self._experience = None
        self._contacts = None
        self._last_name = None
        self._internal = None
        self._ats_id = None
        self.discriminator = None
        if attachments is not None:
            self.attachments = attachments
        if education is not None:
            self.education = education
        if middle_name is not None:
            self.middle_name = middle_name
        if language_preference is not None:
            self.language_preference = language_preference
        if language_known is not None:
            self.language_known = language_known
        if user_id is not None:
            self.user_id = user_id
        if last_update_timestamp is not None:
            self.last_update_timestamp = last_update_timestamp
        if employee_id is not None:
            self.employee_id = employee_id
        if skills is not None:
            self.skills = skills
        if linked_in_profile_url is not None:
            self.linked_in_profile_url = linked_in_profile_url
        if first_name is not None:
            self.first_name = first_name
        if company is not None:
            self.company = company
        if created_date is not None:
            self.created_date = created_date
        if new_location is not None:
            self.new_location = new_location
        if updated_date is not None:
            self.updated_date = updated_date
        if preferred_communication_mode is not None:
            self.preferred_communication_mode = preferred_communication_mode
        if email_list is not None:
            self.email_list = email_list
        if experience is not None:
            self.experience = experience
        if contacts is not None:
            self.contacts = contacts
        if last_name is not None:
            self.last_name = last_name
        if internal is not None:
            self.internal = internal
        if ats_id is not None:
            self.ats_id = ats_id

    @property
    def attachments(self):
        """Gets the attachments of this CandidateDataCandidate.  # noqa: E501

        Array containing details of attachments associated with the candidate.  # noqa: E501

        :return: The attachments of this CandidateDataCandidate.  # noqa: E501
        :rtype: list[CandidateDataCandidateAttachments]
        """
        return self._attachments

    @attachments.setter
    def attachments(self, attachments):
        """Sets the attachments of this CandidateDataCandidate.

        Array containing details of attachments associated with the candidate.  # noqa: E501

        :param attachments: The attachments of this CandidateDataCandidate.  # noqa: E501
        :type: list[CandidateDataCandidateAttachments]
        """

        self._attachments = attachments

    @property
    def education(self):
        """Gets the education of this CandidateDataCandidate.  # noqa: E501

        Array containing objects representing the educational background of the candidate.  # noqa: E501

        :return: The education of this CandidateDataCandidate.  # noqa: E501
        :rtype: list[EducationDataEducations]
        """
        return self._education

    @education.setter
    def education(self, education):
        """Sets the education of this CandidateDataCandidate.

        Array containing objects representing the educational background of the candidate.  # noqa: E501

        :param education: The education of this CandidateDataCandidate.  # noqa: E501
        :type: list[EducationDataEducations]
        """

        self._education = education

    @property
    def middle_name(self):
        """Gets the middle_name of this CandidateDataCandidate.  # noqa: E501

        The middle name of the candidate.  # noqa: E501

        :return: The middle_name of this CandidateDataCandidate.  # noqa: E501
        :rtype: str
        """
        return self._middle_name

    @middle_name.setter
    def middle_name(self, middle_name):
        """Sets the middle_name of this CandidateDataCandidate.

        The middle name of the candidate.  # noqa: E501

        :param middle_name: The middle_name of this CandidateDataCandidate.  # noqa: E501
        :type: str
        """

        self._middle_name = middle_name

    @property
    def language_preference(self):
        """Gets the language_preference of this CandidateDataCandidate.  # noqa: E501

        The language preference of the candidate.  # noqa: E501

        :return: The language_preference of this CandidateDataCandidate.  # noqa: E501
        :rtype: str
        """
        return self._language_preference

    @language_preference.setter
    def language_preference(self, language_preference):
        """Sets the language_preference of this CandidateDataCandidate.

        The language preference of the candidate.  # noqa: E501

        :param language_preference: The language_preference of this CandidateDataCandidate.  # noqa: E501
        :type: str
        """

        self._language_preference = language_preference

    @property
    def language_known(self):
        """Gets the language_known of this CandidateDataCandidate.  # noqa: E501

        List of languages known by the candidate.  # noqa: E501

        :return: The language_known of this CandidateDataCandidate.  # noqa: E501
        :rtype: list[str]
        """
        return self._language_known

    @language_known.setter
    def language_known(self, language_known):
        """Sets the language_known of this CandidateDataCandidate.

        List of languages known by the candidate.  # noqa: E501

        :param language_known: The language_known of this CandidateDataCandidate.  # noqa: E501
        :type: list[str]
        """

        self._language_known = language_known

    @property
    def user_id(self):
        """Gets the user_id of this CandidateDataCandidate.  # noqa: E501

        Unique identifier for the user or candidate.  # noqa: E501

        :return: The user_id of this CandidateDataCandidate.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this CandidateDataCandidate.

        Unique identifier for the user or candidate.  # noqa: E501

        :param user_id: The user_id of this CandidateDataCandidate.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def last_update_timestamp(self):
        """Gets the last_update_timestamp of this CandidateDataCandidate.  # noqa: E501

        Timestamp indicating the last update time of the candidate's profile.  # noqa: E501

        :return: The last_update_timestamp of this CandidateDataCandidate.  # noqa: E501
        :rtype: float
        """
        return self._last_update_timestamp

    @last_update_timestamp.setter
    def last_update_timestamp(self, last_update_timestamp):
        """Sets the last_update_timestamp of this CandidateDataCandidate.

        Timestamp indicating the last update time of the candidate's profile.  # noqa: E501

        :param last_update_timestamp: The last_update_timestamp of this CandidateDataCandidate.  # noqa: E501
        :type: float
        """

        self._last_update_timestamp = last_update_timestamp

    @property
    def employee_id(self):
        """Gets the employee_id of this CandidateDataCandidate.  # noqa: E501

        Employee profile ID associated with the candidate.  # noqa: E501

        :return: The employee_id of this CandidateDataCandidate.  # noqa: E501
        :rtype: str
        """
        return self._employee_id

    @employee_id.setter
    def employee_id(self, employee_id):
        """Sets the employee_id of this CandidateDataCandidate.

        Employee profile ID associated with the candidate.  # noqa: E501

        :param employee_id: The employee_id of this CandidateDataCandidate.  # noqa: E501
        :type: str
        """

        self._employee_id = employee_id

    @property
    def skills(self):
        """Gets the skills of this CandidateDataCandidate.  # noqa: E501

        List of skills possessed by the candidate.  # noqa: E501

        :return: The skills of this CandidateDataCandidate.  # noqa: E501
        :rtype: list[str]
        """
        return self._skills

    @skills.setter
    def skills(self, skills):
        """Sets the skills of this CandidateDataCandidate.

        List of skills possessed by the candidate.  # noqa: E501

        :param skills: The skills of this CandidateDataCandidate.  # noqa: E501
        :type: list[str]
        """

        self._skills = skills

    @property
    def linked_in_profile_url(self):
        """Gets the linked_in_profile_url of this CandidateDataCandidate.  # noqa: E501

        URL to the candidate's LinkedIn profile.  # noqa: E501

        :return: The linked_in_profile_url of this CandidateDataCandidate.  # noqa: E501
        :rtype: str
        """
        return self._linked_in_profile_url

    @linked_in_profile_url.setter
    def linked_in_profile_url(self, linked_in_profile_url):
        """Sets the linked_in_profile_url of this CandidateDataCandidate.

        URL to the candidate's LinkedIn profile.  # noqa: E501

        :param linked_in_profile_url: The linked_in_profile_url of this CandidateDataCandidate.  # noqa: E501
        :type: str
        """

        self._linked_in_profile_url = linked_in_profile_url

    @property
    def first_name(self):
        """Gets the first_name of this CandidateDataCandidate.  # noqa: E501

        First name of the candidate.  # noqa: E501

        :return: The first_name of this CandidateDataCandidate.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this CandidateDataCandidate.

        First name of the candidate.  # noqa: E501

        :param first_name: The first_name of this CandidateDataCandidate.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def company(self):
        """Gets the company of this CandidateDataCandidate.  # noqa: E501

        The name of the company associated with the candidate.  # noqa: E501

        :return: The company of this CandidateDataCandidate.  # noqa: E501
        :rtype: str
        """
        return self._company

    @company.setter
    def company(self, company):
        """Sets the company of this CandidateDataCandidate.

        The name of the company associated with the candidate.  # noqa: E501

        :param company: The company of this CandidateDataCandidate.  # noqa: E501
        :type: str
        """

        self._company = company

    @property
    def created_date(self):
        """Gets the created_date of this CandidateDataCandidate.  # noqa: E501

        A timestamp indicating the date and time when the candidate profile was created.  # noqa: E501

        :return: The created_date of this CandidateDataCandidate.  # noqa: E501
        :rtype: float
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this CandidateDataCandidate.

        A timestamp indicating the date and time when the candidate profile was created.  # noqa: E501

        :param created_date: The created_date of this CandidateDataCandidate.  # noqa: E501
        :type: float
        """

        self._created_date = created_date

    @property
    def new_location(self):
        """Gets the new_location of this CandidateDataCandidate.  # noqa: E501


        :return: The new_location of this CandidateDataCandidate.  # noqa: E501
        :rtype: CandidateDataCandidateNewLocation
        """
        return self._new_location

    @new_location.setter
    def new_location(self, new_location):
        """Sets the new_location of this CandidateDataCandidate.


        :param new_location: The new_location of this CandidateDataCandidate.  # noqa: E501
        :type: CandidateDataCandidateNewLocation
        """

        self._new_location = new_location

    @property
    def updated_date(self):
        """Gets the updated_date of this CandidateDataCandidate.  # noqa: E501

        The date when the information was last updated.  # noqa: E501

        :return: The updated_date of this CandidateDataCandidate.  # noqa: E501
        :rtype: float
        """
        return self._updated_date

    @updated_date.setter
    def updated_date(self, updated_date):
        """Sets the updated_date of this CandidateDataCandidate.

        The date when the information was last updated.  # noqa: E501

        :param updated_date: The updated_date of this CandidateDataCandidate.  # noqa: E501
        :type: float
        """

        self._updated_date = updated_date

    @property
    def preferred_communication_mode(self):
        """Gets the preferred_communication_mode of this CandidateDataCandidate.  # noqa: E501


        :return: The preferred_communication_mode of this CandidateDataCandidate.  # noqa: E501
        :rtype: CandidateDataCandidatePreferredCommunicationMode
        """
        return self._preferred_communication_mode

    @preferred_communication_mode.setter
    def preferred_communication_mode(self, preferred_communication_mode):
        """Sets the preferred_communication_mode of this CandidateDataCandidate.


        :param preferred_communication_mode: The preferred_communication_mode of this CandidateDataCandidate.  # noqa: E501
        :type: CandidateDataCandidatePreferredCommunicationMode
        """

        self._preferred_communication_mode = preferred_communication_mode

    @property
    def email_list(self):
        """Gets the email_list of this CandidateDataCandidate.  # noqa: E501

        An array representing an email list.  # noqa: E501

        :return: The email_list of this CandidateDataCandidate.  # noqa: E501
        :rtype: list[CandidateDataCandidateEmailList]
        """
        return self._email_list

    @email_list.setter
    def email_list(self, email_list):
        """Sets the email_list of this CandidateDataCandidate.

        An array representing an email list.  # noqa: E501

        :param email_list: The email_list of this CandidateDataCandidate.  # noqa: E501
        :type: list[CandidateDataCandidateEmailList]
        """

        self._email_list = email_list

    @property
    def experience(self):
        """Gets the experience of this CandidateDataCandidate.  # noqa: E501

        An array representing professional experiences.  # noqa: E501

        :return: The experience of this CandidateDataCandidate.  # noqa: E501
        :rtype: list[CandidateDataCandidateExperience]
        """
        return self._experience

    @experience.setter
    def experience(self, experience):
        """Sets the experience of this CandidateDataCandidate.

        An array representing professional experiences.  # noqa: E501

        :param experience: The experience of this CandidateDataCandidate.  # noqa: E501
        :type: list[CandidateDataCandidateExperience]
        """

        self._experience = experience

    @property
    def contacts(self):
        """Gets the contacts of this CandidateDataCandidate.  # noqa: E501

        An array representing contact information for the individual.  # noqa: E501

        :return: The contacts of this CandidateDataCandidate.  # noqa: E501
        :rtype: list[CandidateDataCandidateContacts]
        """
        return self._contacts

    @contacts.setter
    def contacts(self, contacts):
        """Sets the contacts of this CandidateDataCandidate.

        An array representing contact information for the individual.  # noqa: E501

        :param contacts: The contacts of this CandidateDataCandidate.  # noqa: E501
        :type: list[CandidateDataCandidateContacts]
        """

        self._contacts = contacts

    @property
    def last_name(self):
        """Gets the last_name of this CandidateDataCandidate.  # noqa: E501

        A string representing the last name of the individual.  # noqa: E501

        :return: The last_name of this CandidateDataCandidate.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this CandidateDataCandidate.

        A string representing the last name of the individual.  # noqa: E501

        :param last_name: The last_name of this CandidateDataCandidate.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def internal(self):
        """Gets the internal of this CandidateDataCandidate.  # noqa: E501

        A boolean indicating whether the individual is internal to the organization.  # noqa: E501

        :return: The internal of this CandidateDataCandidate.  # noqa: E501
        :rtype: bool
        """
        return self._internal

    @internal.setter
    def internal(self, internal):
        """Sets the internal of this CandidateDataCandidate.

        A boolean indicating whether the individual is internal to the organization.  # noqa: E501

        :param internal: The internal of this CandidateDataCandidate.  # noqa: E501
        :type: bool
        """

        self._internal = internal

    @property
    def ats_id(self):
        """Gets the ats_id of this CandidateDataCandidate.  # noqa: E501

        A string representing the unique identifier associated with the Applicant Tracking System (ATS).  # noqa: E501

        :return: The ats_id of this CandidateDataCandidate.  # noqa: E501
        :rtype: str
        """
        return self._ats_id

    @ats_id.setter
    def ats_id(self, ats_id):
        """Sets the ats_id of this CandidateDataCandidate.

        A string representing the unique identifier associated with the Applicant Tracking System (ATS).  # noqa: E501

        :param ats_id: The ats_id of this CandidateDataCandidate.  # noqa: E501
        :type: str
        """

        self._ats_id = ats_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CandidateDataCandidate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CandidateDataCandidate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
